#!/usr/bin/ruby -w
# Encoding: UTF-8
# frozen_string_literal: true
# =========================================================================== #
# === Extracter::Base
#
# Usage example:
#
#   Extracter::Base.new(ARGV)
#
# =========================================================================== #
# require 'extracter/base/base.rb'; < ::Extracter::Base
# =========================================================================== #
module Extracter

class Base # === Extracter::Base

  begin
    require 'colours'
  rescue LoadError; end

  # ========================================================================= #
  # === reset
  # ========================================================================= #
  def reset
    # ======================================================================= #
    # === @internal_hash
    # ======================================================================= #
    @internal_hash = {}
    # ======================================================================= #
    # === :use_colours
    # ======================================================================= #
    @internal_hash[:use_colours] = true
  end

  # ========================================================================= #
  # === cyan
  # ========================================================================= #
  def cyan?
    return Colours::CYAN if Object.const_defined?(:Colours) and use_colours?
    return ''
  end

  # ========================================================================= #
  # === tomato
  # ========================================================================= #
  def tomato(i = '')
    return Colours.tomato(i) if use_colours?
    return i
  end

  # ========================================================================= #
  # === simp
  # ========================================================================= #
  def simp(i = '')
    return Colours.simp(i) if use_colours?
    return i
  end

  # ========================================================================= #
  # === ewarn
  # ========================================================================= #
  def ewarn(i = '')
    if use_colours? and Object.const_defined?(:Colours)
      e Colours.swarn(i)
    else
      e i
    end
  end

  # ========================================================================= #
  # === sfile
  # ========================================================================= #
  def sfile(i = '')
    return Colours.sfancy(i) if use_colours?
    return i
  end

  # ========================================================================= #
  # === sfancy
  # ========================================================================= #
  def sfancy(i = '')
    return Colours.sfancy(i) if use_colours?
    return i
  end

  # ========================================================================= #
  # === sdir
  # ========================================================================= #
  def sdir(i = '')
    return Colours.sdir(i) if use_colours?
    return i
  end

  # ========================================================================= #
  # === use_colours?
  #
  # Determine whether we will use colours in class Extracter.
  # ========================================================================= #
  def use_colours?
    @internal_hash[:use_colours]
  end; alias colours? use_colours? # === colours?

  # ========================================================================= #
  # === e                                                             (e tag)
  # ========================================================================= #
  def e(i = '')
    puts i
  end

  # ========================================================================= #
  # === cpr
  # ========================================================================= #
  def cpr(a, b)
    require 'fileutils' unless Object.const_defined?(:FileUtils)
    FileUtils.cp_r(a, b)
  end

  # ========================================================================= #
  # === move
  # ========================================================================= #
  def move(a, b)
    require 'fileutils' unless Object.const_defined?(:FileUtils)
    FileUtils.mv(a, b)
  end; alias mv move # === mv

  # ========================================================================= #
  # === remove_this_directory
  # ========================================================================= #
  def remove_this_directory(i)
    if File.directory? i
      FileUtils.rm_r(i) unless i == '/'
    end
  end

  # ========================================================================= #
  # === change_directory
  # ========================================================================= #
  def change_directory(i)
    Dir.chdir(i)
  end; alias cd change_directory # === cd

end; end

if __FILE__ == $PROGRAM_NAME
  Extracter::Extracter.new(ARGV)
end # base.rb